@@ -21,7 +21,7 @@ from threading import Lock
 from uuid import uuid4
 
 from lisp.core.configuration import config
-from lisp.core.decorators import async
+from lisp.core.decorators import async_function
 from lisp.core.fade_functions import FadeInType, FadeOutType
 from lisp.core.has_properties import HasProperties, Property, WriteOnceProperty
 from lisp.core.rwait import RWait
@@ -206,7 +206,7 @@ class Cue(HasProperties):
                 fade_type = FadeInType[config['Cue'].get('FadeActionType')]
                 self.fadein(duration, fade_type)
 
-    @async
+    @async_function
     def start(self, fade=False):
         """Start the cue."""
 
@@ -292,7 +292,7 @@ class Cue(HasProperties):
         """
         return False
 
-    @async
+    @async_function
     def stop(self, fade=False):
         """Stop the cue."""
 
@@ -350,7 +350,7 @@ class Cue(HasProperties):
         """
         return False
 
-    @async
+    @async_function
     def pause(self, fade=False):
         """Pause the cue."""
 
@@ -404,7 +404,7 @@ class Cue(HasProperties):
         """
         return False
 
-    @async
+    @async_function
     def interrupt(self, fade=False):
         """Interrupt the cue.
 
